@@ -36,6 +36,10 @@ int main(int argc, char **argv)
     // Enable debug output:
     // QLoggingCategory::setFilterRules(QStringLiteral("ksystemlog.debug = true"));
 
+    // enable high dpi support
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("ksystemlog");
